@@ -578,8 +578,7 @@ void* hildon_home_applet_lib_initialize(void *state_data,
 */
 #if HILDON == 1		     
     app->signal_expose = g_signal_connect(app->top_widget, "expose-event",
-                     G_CALLBACK (expose_main_window),
-                     NULL);
+                     G_CALLBACK (expose_main_window), NULL);
     app->widget_first_start = FALSE;		     
 
     gtk_widget_set_name(GTK_WIDGET(app->top_widget), "omweather");		    
