@@ -96,7 +96,7 @@ enum {	METERS_S,
 */	KILOMETERS_H,
 	MILES_H };
 enum { CELSIUS, FAHRENHEIT };
-enum {  GIANT, LARGE, MEDIUM, SMALL, TINY  };
+enum {  UNKNOWN, TINY, SMALL, MEDIUM, LARGE, GIANT };
 /*******************************************************************************/
 typedef struct{
     gchar	speed[80];		/* wind speed */
