@@ -239,6 +239,8 @@ int new_read_config(AppletConfig *config){
     /* Get Weather Station ID for current station */
     config->current_station_id = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_CURRENT_STATION_ID, NULL);
+    if(!config->current_station_id)
+	config->current_station_id = NULL;
     /* Get Weather Stations ID and NAME */
     stlist = gconf_client_get_list(gconf_client,
         			    GCONF_KEY_WEATHER_STATIONS_LIST,
@@ -259,13 +261,13 @@ int new_read_config(AppletConfig *config){
     }
     else
 	close(fd);
-    /* Get Weather Icon Size  */		     
+    /* Get Weather Icon Size  */
     config->icons_size = gconf_client_get_int(gconf_client,
         				    GCONF_KEY_WEATHER_ICONS_SIZE,
 					    NULL);
-    if(config->icons_size < GIANT || config->icons_size > TINY)
+    if(config->icons_size < TINY || config->icons_size > GIANT)
         config->icons_size = LARGE;
-
+    
     /* Get setting tab number  */		     
     config->current_settings_page = gconf_client_get_int(gconf_client,
         				    GCONF_KEY_WEATHER_SETTING_TAB_NUMBER,
@@ -429,8 +431,28 @@ int new_read_config(AppletConfig *config){
     else{
 	/* Correcting icon size for version less 0.19.5. It  must be deleted after version 0.21 */
 	if (tmp[0]=='0' && tmp[2]<'2' && tmp[3]<='9' && tmp[5]<'5'){
-	    config->icons_size = config->icons_size + 2;
-	    if(config->icons_size < GIANT || config->icons_size > TINY)
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 0)	
+		config->icons_size = MEDIUM;
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 1)	
+		config->icons_size = SMALL;		
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 2)	
+		config->icons_size = TINY;				
+	    if(config->icons_size < TINY || config->icons_size > GIANT)
+    		config->icons_size = LARGE;
+	}
+	/* Correcting icon size for version  0.19.5. It  must be deleted after version 0.21 */
+	if (tmp[0]=='0' && tmp[2]=='1' && tmp[3]=='9' && tmp[5]=='5'){
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 0)	
+		config->icons_size = GIANT;
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 1)	
+		config->icons_size = LARGE;		
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 2)	
+		config->icons_size = MEDIUM;			
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 3)	
+		config->icons_size = SMALL;						
+	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 4)	
+		config->icons_size = TINY;			
+	    if(config->icons_size < TINY || config->icons_size > GIANT)
     		config->icons_size = LARGE;
 	}
 	g_free(tmp);		     
