@@ -51,8 +51,8 @@ weather_com_parser *weather_parser_new_from_file(const gchar *filename){
 /*******************************************************************************/
 int parse_weather_com_xml(void){
     weather_com_parser	*parser;
-    xmlNode	*cur_node	= NULL,
-		*child_node	= NULL,
+    xmlNode	*cur_node = NULL,
+		*child_node = NULL,
 		*child_node2 = NULL,
 		*child_node3 = NULL,
 		*child_node4 = NULL; 
@@ -71,14 +71,6 @@ int parse_weather_com_xml(void){
 		newname[2048];
     time_t	current_time;
     struct tm	*tm;
-/*  fprintf (stderr, "vlad: %s",get_weather_html());
-    http://xoap.weather.com/weather/local/BOXX0014?cc=*&prod=xoap&par=1004517364&key=a29796f587f206b2&unit=m&dayf=5
-    http://www.weather.com/weather/mpdwcr/tenday?locid=BOXX0014&channel=other&datapoint=htempdp&adprodname=pif_undcl_tenday_long
-    http://yolinux.com/TUTORIALS/GnomeLibXml2.html
-    $par = "1005217190";
-    $key = "2e4490982af206e0";
-    http://www.rap.ucar.edu/weather/surface/stations.txt
-*/
 
 /*Prepare date string */
 /* Imortant need will Check New Year in future !!!!!!!!!!! */
@@ -87,32 +79,39 @@ int parse_weather_com_xml(void){
     year = 1900 + tm->tm_year;
     parser = NULL;
     
-    if(!app->current_station_id)
+    if(!app->config->current_station_id)
 	return -1;
-    sprintf(buffer, "%s/%s.xml.new", app->weather_dir_name,
-				    app->current_station_id); /* Used new file */
-    if(!access(buffer,R_OK)){  /* Not Access to cache weather xml file */
+    sprintf(buffer, "%s/%s.xml.new", app->config->cache_dir_name,
+				    app->config->current_station_id); /* Used new file */
+    if(!access(buffer, R_OK)){  /* Not Access to cache weather xml file */
 	parser = weather_parser_new_from_file(buffer); 
 	    if(!(parser->error)){
-		sprintf(newname, "%s/%s.xml", app->weather_dir_name,
-			    app->current_station_id);
-		rename(buffer,newname);
+		sprintf(newname, "%s/%s.xml", app->config->cache_dir_name,
+			    app->config->current_station_id);
+		rename(buffer, newname);
 	    }
     }
-    if(((parser == NULL) &&(access (buffer,R_OK) != 0)) || (parser != NULL && parser->error)){ /* Used old xml file */
-    	if (parser) free(parser);
-	sprintf(buffer, "%s/%s.xml", app->weather_dir_name,
-		app->current_station_id);
+    if(((parser == NULL) && (access(buffer,R_OK) != 0)) || (parser != NULL && parser->error)){ /* Used old xml file */
+    	if(parser){
+	    free(parser);
+	    parser = NULL;
+	}    
+	sprintf(buffer, "%s/%s.xml", app->config->cache_dir_name,
+		app->config->current_station_id);
 	/* Not Access to cache weather xml file or not valid XML file */
 	if(!access(buffer,R_OK)){ 
 	    parser = weather_parser_new_from_file(buffer);
-	    if (parser->error){
+	    if(parser->error){
 		free(parser);
+		parser = NULL;
 		return -1; 
 	    }	
 	}
 	else{
-	    free(parser);
+	    if(parser){			
+		free(parser);
+		parser = NULL;
+	    }
 	    return -1;
 	}    
     }
@@ -121,37 +120,41 @@ int parse_weather_com_xml(void){
 	if( cur_node->type == XML_ELEMENT_NODE ){
         /* Check error */
 	    if(!xmlStrcmp(cur_node->name, (const xmlChar *) "err" ) ){
+	        xmlFreeDoc(parser->doc);
+		xmlCleanupParser();
 		free(parser);
 		return -2;
-	    }	
+	    }
         /* Fill all buttons Location data */
     	    if(!xmlStrcmp(cur_node->name, (const xmlChar *) "loc" ) ){
 		temp_xml_string = xmlGetProp(cur_node, (const xmlChar*)"id");
-		sprintf(id_station, "%.8s", temp_xml_string);
+		snprintf(id_station,
+			    sizeof(id_station) - 1,
+			    "%s", temp_xml_string);
 		xmlFree(temp_xml_string);
 	 /* If station in xml not station in config file exit */ 
-		if( strcmp(id_station, app->current_station_id) != 0 ){
+		if( strcmp(id_station, app->config->current_station_id) ){
 		    free(parser);
 		    return -1;
-		}    
+		}
 /*	 fprintf(stderr,"Element: %s \n", cur_node->name); */
 		for(child_node = cur_node->children; child_node != NULL; child_node = child_node->next){
 		    if( child_node->type == XML_ELEMENT_NODE  && 
 			    ( !xmlStrcmp(child_node->name, (const xmlChar *)"dnam") ) ){
 			for (i = 0; i < Max_count_weather_day; i++){
 			    temp_xml_string = xmlNodeGetContent(child_node);
-			    snprintf(weather_days[i].location, sizeof(weather_days[i].location) - 1, "%s",temp_xml_string);
+			    snprintf(app->weather_days[i].location, sizeof(app->weather_days[i].location) - 1, "%s",temp_xml_string);
 			    xmlFree(temp_xml_string);
 			}    
-		    }	
-		    if( child_node->type == XML_ELEMENT_NODE  && 
-			    ( !xmlStrcmp(child_node->name, (const xmlChar *)"zone") ) ){
-			for (i = 0; i < Max_count_weather_day; i++){
-			    temp_xml_string = xmlNodeGetContent(child_node);
-			    weather_days[i].zone = atol((char*)temp_xml_string) * 60 * 60;
-			    xmlFree(temp_xml_string);
+		    }
+		    if( child_node->type == XML_ELEMENT_NODE  &&
+                	    ( !xmlStrcmp(child_node->name, (const xmlChar *)"zone") ) ){
+                	for(i = 0; i < Max_count_weather_day; i++){
+                    	    temp_xml_string = xmlNodeGetContent(child_node);
+                	    app->weather_days[i].zone = atol((char*)temp_xml_string) * 60 * 60;
+                    	    xmlFree(temp_xml_string);
 			}
-		    }	
+        	    }
 		}
 	    }
 	/* Fill current day */
@@ -164,28 +167,32 @@ int parse_weather_com_xml(void){
 			xmlFree(temp_xml_string);
 			strptime(date_in_string, "%D %I:%M", tm);
 			current_month = tm->tm_mon;
-			weather_current_day.date_time = mktime(tm);	    
+			app->weather_current_day.date_time = mktime(tm);
 			temp_string_pointer = strchr(date_in_string,'M');
 	    /* Add 12 hours if  date have PM field */
 			if(*(temp_string_pointer - 1) == 'P')
-			    weather_current_day.date_time = weather_current_day.date_time + 12 * 3600;
+			    app->weather_current_day.date_time = app->weather_current_day.date_time + 12 * 3600;
 		    }	
 		    if( child_node->type == XML_ELEMENT_NODE  &&
         		    ( !xmlStrcmp(child_node->name, (const xmlChar *)"tmp") ) ){
 			temp_xml_string = xmlNodeGetContent(child_node);			
-			sprintf(weather_current_day.day.temp,"%.3s", temp_xml_string);
+			snprintf(app->weather_current_day.day.temp,
+				sizeof(app->weather_current_day.day.temp) - 1,
+				"%s", temp_xml_string);
 			xmlFree(temp_xml_string);
 		    }
     		    if( child_node->type == XML_ELEMENT_NODE  &&
             		    ( !xmlStrcmp(child_node->name, (const xmlChar *)"flik") ) ){
 			temp_xml_string = xmlNodeGetContent(child_node);			    
-    			sprintf(weather_current_day.low_temp,"%.3s", temp_xml_string);
+    			snprintf(app->weather_current_day.low_temp,
+				    sizeof(app->weather_current_day.low_temp) - 1,
+				    "%s", temp_xml_string);
 			xmlFree(temp_xml_string);
 		    }	
 		    if(!xmlStrcmp(child_node->name, (const xmlChar *)"t") ){
 			temp_xml_string = xmlNodeGetContent(child_node);			
-    			snprintf(weather_current_day.day.title,
-				 sizeof(weather_current_day.day.title) - 1,
+    			snprintf(app->weather_current_day.day.title,
+				 sizeof(app->weather_current_day.day.title) - 1,
 				 "%s",
 				 (char*)hash_table_find(temp_xml_string));
 			xmlFree(temp_xml_string);	 
@@ -193,7 +200,7 @@ int parse_weather_com_xml(void){
     		    if(!xmlStrcmp(child_node->name, (const xmlChar *)"icon") ){
 			temp_xml_string = xmlNodeGetContent(child_node);					    
     			icon = (char*) temp_xml_string;
-    			weather_current_day.day.icon=atoi(icon);
+    			app->weather_current_day.day.icon=atoi(icon);
 			xmlFree(temp_xml_string);	 
         	    }
     		    if(!xmlStrcmp(child_node->name, (const xmlChar *)"bar") ){
@@ -201,13 +208,13 @@ int parse_weather_com_xml(void){
     			    if( child_node2->type == XML_ELEMENT_NODE ){
         			if(!xmlStrcmp(child_node2->name, (const xmlChar *)"r") ){
 				    temp_xml_string = xmlNodeGetContent(child_node2);			
-        			    weather_current_day.day.pressure = atof((char*)temp_xml_string);
+        			    app->weather_current_day.day.pressure = atof((char*)temp_xml_string);
 				    xmlFree(temp_xml_string);	 				    
 				}    
     				if(!xmlStrcmp(child_node2->name, (const xmlChar *)"d") ){
 				    temp_xml_string = xmlNodeGetContent(child_node2);			
-        			    snprintf(weather_current_day.day.pressure_str,
-					     sizeof(weather_current_day.day.pressure_str) - 1,
+        			    snprintf(app->weather_current_day.day.pressure_str,
+					     sizeof(app->weather_current_day.day.pressure_str) - 1,
 					     "%s",
 					     (char*)hash_table_find(temp_xml_string));
 				    xmlFree(temp_xml_string);	 				    
@@ -217,13 +224,15 @@ int parse_weather_com_xml(void){
         	    }
 		    if(!xmlStrcmp(child_node->name, (const xmlChar *)"hmid") ){
     			temp_xml_string = xmlNodeGetContent(child_node);					    
-    			sprintf(weather_current_day.day.hmid,"%.3s",temp_xml_string);
+    			snprintf(app->weather_current_day.day.hmid,
+				sizeof(app->weather_current_day.day.hmid) - 1,
+				"%s", temp_xml_string);
 			xmlFree(temp_xml_string);	 				    
 		    }	
     		    if(!xmlStrcmp(child_node->name, (const xmlChar *)"vis") ){
 			temp_xml_string = xmlNodeGetContent(child_node);					    
-			snprintf(weather_current_day.day.vis,
-				sizeof(weather_current_day.day.vis) - 1,
+			snprintf(app->weather_current_day.day.vis,
+				sizeof(app->weather_current_day.day.vis) - 1,
 				"%s",
 				(char*)temp_xml_string);
 			xmlFree(temp_xml_string);
@@ -233,31 +242,50 @@ int parse_weather_com_xml(void){
     			    if( child_node2->type == XML_ELEMENT_NODE ){
         			if(!xmlStrcmp(child_node2->name, (const xmlChar *)"s") ){
 				    temp_xml_string = xmlNodeGetContent(child_node2);			
-        			    snprintf(weather_current_day.day.wind_speed,
-					    sizeof(weather_current_day.day.wind_speed) - 1,
+        			    snprintf(app->weather_current_day.day.wind_speed,
+					    sizeof(app->weather_current_day.day.wind_speed) - 1,
 					    "%s", 
         				    (char*)temp_xml_string);
 				    xmlFree(temp_xml_string);
 				}
         			if(!xmlStrcmp(child_node2->name, (const xmlChar *)"gust") ){
 				    temp_xml_string = xmlNodeGetContent(child_node2);							
-				    snprintf(weather_current_day.day.wind_gust,
-					    sizeof(weather_current_day.day.wind_gust) - 1,
+				    snprintf(app->weather_current_day.day.wind_gust,
+					    sizeof(app->weather_current_day.day.wind_gust) - 1,
 					    "%s", 
         				    (char*)temp_xml_string);
 				    xmlFree(temp_xml_string);
 				}
     				if(!xmlStrcmp(child_node2->name, (const xmlChar *)"t") ){
 				    temp_xml_string = xmlNodeGetContent(child_node2);							
-        			    snprintf(weather_current_day.day.wind_title,
-					     sizeof(weather_current_day.day.wind_title) - 1,
+        			    snprintf(app->weather_current_day.day.wind_title,
+					     sizeof(app->weather_current_day.day.wind_title) - 1,
 					     "%s",
 					     (char*)hash_table_find(temp_xml_string));
 				    xmlFree(temp_xml_string);
 				}
 			    }
         		}
-        	    }         
+        	    }
+		    if(!xmlStrcmp(child_node->name, (const xmlChar *)"moon") ){
+			for(child_node2 = child_node->children; child_node2 != NULL; child_node2 = child_node2->next){
+    			    if( child_node2->type == XML_ELEMENT_NODE ){
+        			if(!xmlStrcmp(child_node2->name, (const xmlChar *)"icon") ){
+				    temp_xml_string = xmlNodeGetContent(child_node2);			
+        			    app->weather_current_day.day.moon_icon = atoi((char*)temp_xml_string);
+				    xmlFree(temp_xml_string);
+				}
+        			if(!xmlStrcmp(child_node2->name, (const xmlChar *)"t") ){
+				    temp_xml_string = xmlNodeGetContent(child_node2);							
+				    snprintf(app->weather_current_day.day.moon,
+					    sizeof(app->weather_current_day.day.moon) - 1,
+					    "%s", 
+        				    (char*)temp_xml_string);
+				    xmlFree(temp_xml_string);
+				}
+			    }
+        		}
+        	    }
 		}
 	    }
 	    if(!xmlStrcmp(cur_node->name, (const xmlChar *) "dayf" ) ){
@@ -268,38 +296,36 @@ int parse_weather_com_xml(void){
 			    count_day++; 
 			    temp_xml_string = xmlGetProp(child_node, (const xmlChar*)"t");
 			    memset(buffer, 0, sizeof(buffer));
-			    memcpy(buffer, temp_xml_string,
-				    (sizeof(buffer) > strlen((char*)temp_xml_string)) ? strlen((char*)temp_xml_string)
-										: sizeof(buffer));
+			    snprintf(buffer, sizeof(buffer) - 1, "%s", temp_xml_string);
 			    strptime(buffer, "%A", tm);
-			    memset(weather_days[count_day - 1].dayshname, 0,
-				    sizeof(weather_days[count_day - 1].dayshname));
-			    strftime(weather_days[count_day-1].dayshname,
-			            sizeof(weather_days[count_day-1].dayshname) - 1,
+                    	    memset(app->weather_days[count_day-1].dayshname, 0,
+				    sizeof(app->weather_days[count_day-1].dayshname));
+			    strftime(app->weather_days[count_day-1].dayshname,
+				    sizeof(app->weather_days[count_day-1].dayshname) - 1,
 				    "%a", tm);
 			    xmlFree(temp_xml_string);
 			    temp_xml_string = xmlGetProp(child_node, (const xmlChar*)"t");
-			    memset(weather_days[count_day - 1].dayfuname, 0,
-				    sizeof(weather_days[count_day - 1].dayfuname));
-			    snprintf(weather_days[count_day - 1].dayfuname,
-				     sizeof(weather_days[count_day-1].dayfuname) - 1, "%s",
+			    memset(app->weather_days[count_day-1].dayfuname, 0,
+				    sizeof(app->weather_days[count_day-1].dayfuname));
+			    snprintf(app->weather_days[count_day-1].dayfuname,
+				     sizeof(app->weather_days[count_day-1].dayfuname) - 1, "%s",
 				     temp_xml_string);
 			    xmlFree(temp_xml_string);				     
 
 			    temp_xml_string = xmlGetProp(child_node, (const xmlChar*)"dt");
-			    snprintf(weather_days[count_day-1].date,
-        			     sizeof(weather_days[count_day-1].date) - 1,
+			    snprintf(app->weather_days[count_day-1].date,
+        			     sizeof(app->weather_days[count_day-1].date) - 1,
 				     "%s",
 				     (char*)temp_xml_string);
 			    xmlFree(temp_xml_string);				     
-			    sprintf(date_in_string,"%s %i 00:00:00",weather_days[count_day-1].date,year);
+			    sprintf(date_in_string,"%s %i 00:00:00",app->weather_days[count_day-1].date,year);
 			    strptime(date_in_string, "%b %d %Y %T", tm);
 	      /* Check New Year */
 			    if((current_month == 11) && (tm->tm_mon == 0)){
-	    			sprintf(date_in_string,"%s %i 00:00:00",weather_days[count_day-1].date,year+1);
+	    			sprintf(date_in_string,"%s %i 00:00:00",app->weather_days[count_day-1].date,year+1);
 	    			strptime(date_in_string, "%b %d %Y %T", tm);
 			    } 
-			    weather_days[count_day-1].date_time = mktime(tm);
+			    app->weather_days[count_day-1].date_time = mktime(tm);
 			    for(child_node2 = child_node->children; child_node2 != NULL; child_node2 = child_node2->next){
 				if( child_node2->type == XML_ELEMENT_NODE){  
         			    if(!xmlStrcmp(child_node2->name, (const xmlChar *)"part")){
@@ -314,12 +340,16 @@ int parse_weather_com_xml(void){
             					if(!xmlStrcmp(child_node3->name, (const xmlChar *)"hmid") ){
 						    if(!day){
 						        temp_xml_string = xmlNodeGetContent(child_node3);
-							sprintf(weather_days[count_day-1].night.hmid,"%.3s",temp_xml_string);
+							snprintf(app->weather_days[count_day - 1].night.hmid,
+								sizeof(app->weather_days[count_day - 1].night.hmid) - 1,
+								"%s", temp_xml_string);
 							xmlFree(temp_xml_string);
 						    }	
 						    else{
 						        temp_xml_string = xmlNodeGetContent(child_node3);							
-							sprintf(weather_days[count_day-1].day.hmid,"%.3s",temp_xml_string);
+							snprintf(app->weather_days[count_day - 1].day.hmid,
+								sizeof(app->weather_days[count_day - 1].day.hmid) - 1,
+								"%s", temp_xml_string);
 							xmlFree(temp_xml_string);
 						    }
 						    
@@ -327,16 +357,16 @@ int parse_weather_com_xml(void){
 						if(!xmlStrcmp(child_node3->name, (const xmlChar *)"t") ){
 						    if(!day){
 							temp_xml_string = xmlNodeGetContent(child_node3);							
-							snprintf(weather_days[count_day-1].night.title,
-								 sizeof(weather_days[count_day-1].night.title) - 1,
+							snprintf(app->weather_days[count_day-1].night.title,
+								 sizeof(app->weather_days[count_day-1].night.title) - 1,
 								 "%s",
 								 (char*)hash_table_find(temp_xml_string));
 							xmlFree(temp_xml_string);
 						    }								 
 						    else{
 						    	temp_xml_string = xmlNodeGetContent(child_node3);													    
-							snprintf(weather_days[count_day-1].day.title,
-								 sizeof(weather_days[count_day-1].day.title) - 1,
+							snprintf(app->weather_days[count_day-1].day.title,
+								 sizeof(app->weather_days[count_day-1].day.title) - 1,
 								"%s",
 								 (char*)hash_table_find(temp_xml_string));
 							xmlFree(temp_xml_string);								 
@@ -346,9 +376,9 @@ int parse_weather_com_xml(void){
 						    temp_xml_string = xmlNodeGetContent(child_node3);	
 						    icon = (char*)temp_xml_string;	
 						    if(!day)
-							weather_days[count_day-1].night.icon=atoi(icon);
+							app->weather_days[count_day-1].night.icon=atoi(icon);
 						    else
-		    					weather_days[count_day-1].day.icon=atoi(icon);          
+		    					app->weather_days[count_day-1].day.icon=atoi(icon);          
 						    xmlFree(temp_xml_string);								 
 						}
 						if(!xmlStrcmp(child_node3->name, (const xmlChar *)"wind") ){
@@ -357,17 +387,16 @@ int parse_weather_com_xml(void){
 							    if(!xmlStrcmp(child_node4->name, (const xmlChar *)"s") ){
 								if(!day){
 								    temp_xml_string = xmlNodeGetContent(child_node4);	
-								    snprintf(weather_days[count_day-1].night.wind_speed,
-									    sizeof(weather_days[count_day-1].night.wind_speed) - 1,
+								    snprintf(app->weather_days[count_day-1].night.wind_speed,
+									    sizeof(app->weather_days[count_day-1].night.wind_speed) - 1,
 									    "%s",
 									    (char*)temp_xml_string);
 								    xmlFree(temp_xml_string);	
 								}
 								else{
 								    temp_xml_string = xmlNodeGetContent(child_node4);	
-								    snprintf(weather_days[count_day-1].day.wind_speed,
-									    sizeof(weather_days[count_day-1].day.wind_speed) - 1,
-									    "%s",
+								    snprintf(app->weather_days[count_day-1].day.wind_speed,
+									    sizeof(app->weather_days[count_day-1].day.wind_speed) - 1,
 									    (char*)temp_xml_string);
 								    xmlFree(temp_xml_string);
 								}
@@ -375,13 +404,13 @@ int parse_weather_com_xml(void){
 							    if(!xmlStrcmp(child_node4->name, (const xmlChar *)"t") ){
 								temp_xml_string = xmlNodeGetContent(child_node4);
 								if(!day)
-								    snprintf(weather_days[count_day-1].night.wind_title,
-									     sizeof(weather_days[count_day-1].night.wind_title) - 1,
+								    snprintf(app->weather_days[count_day-1].night.wind_title,
+									     sizeof(app->weather_days[count_day-1].night.wind_title) - 1,
 									     "%s",
 									     (char*)hash_table_find(temp_xml_string));
 								else
-								    snprintf(weather_days[count_day-1].day.wind_title,
-									     sizeof(weather_days[count_day-1].day.wind_title) - 1,
+								    snprintf(app->weather_days[count_day - 1].day.wind_title,
+									    sizeof(app->weather_days[count_day - 1].day.wind_title) - 1,
 									    "%s",
 									    (char*)hash_table_find(temp_xml_string));
     								xmlFree(temp_xml_string);
@@ -395,30 +424,38 @@ int parse_weather_com_xml(void){
 	    			    }   	
 				    temp_xml_string = xmlNodeGetContent(child_node2);
 				    if(!xmlStrcmp(child_node2->name, (const xmlChar *)"hi"))
-					sprintf(weather_days[count_day-1].hi_temp,"%.3s", temp_xml_string);
+					snprintf(app->weather_days[count_day - 1].hi_temp,
+						    sizeof(app->weather_days[count_day - 1].hi_temp) - 1,
+						    "%s", temp_xml_string);
 				    if(!xmlStrcmp(child_node2->name, (const xmlChar *)"low"))
-					sprintf(weather_days[count_day-1].low_temp,"%.3s", temp_xml_string);
-				    if(!xmlStrcmp(child_node2->name, (const xmlChar *)"sunr")){ 
-					sprintf(date_in_string,"%s %i %s",weather_days[count_day-1].date,year,temp_xml_string);
+					snprintf(app->weather_days[count_day - 1].low_temp,
+						sizeof(app->weather_days[count_day - 1].low_temp) - 1,
+						"%s", temp_xml_string);
+				    if(!xmlStrcmp(child_node2->name, (const xmlChar *)"sunr")){
+					memcpy(app->weather_days[count_day - 1].sunrise, (char*)temp_xml_string,
+							    sizeof(app->weather_days[count_day - 1].sunrise) - 1);
+					sprintf(date_in_string,"%s %i %s",app->weather_days[count_day-1].date,year,temp_xml_string);
 					strptime(date_in_string, "%b %d %Y %I:%M %p", tm);
-					weather_days[count_day-1].day.begin_time = mktime(tm);
+					app->weather_days[count_day-1].day.begin_time = mktime(tm);
 				    
 		 /* Check New Year */
 					if((current_month == 11) && (tm->tm_mon == 0)){
-					    sprintf(date_in_string,"%s %i %s",weather_days[count_day-1].date,year+1,temp_xml_string);
+					    sprintf(date_in_string,"%s %i %s",app->weather_days[count_day-1].date,year+1,temp_xml_string);
 					    strptime(date_in_string, "%b %d %Y %I:%M %p", tm);
-	    				    weather_days[count_day-1].day.begin_time = mktime(tm);	        
+	    				    app->weather_days[count_day-1].day.begin_time = mktime(tm);	        
 					}
 				    }     
 				    if(!xmlStrcmp(child_node2->name, (const xmlChar *)"suns")){ 
-					sprintf(date_in_string,"%s %i %s",weather_days[count_day-1].date,year,temp_xml_string);
+					memcpy(app->weather_days[count_day - 1].sunset, (char*)temp_xml_string,
+							    sizeof(app->weather_days[count_day - 1].sunset) - 1);
+					sprintf(date_in_string,"%s %i %s",app->weather_days[count_day-1].date,year,temp_xml_string);
 					strptime(date_in_string, "%b %d %Y %I:%M %p", tm);
-					weather_days[count_day-1].night.begin_time = mktime(tm);
+					app->weather_days[count_day-1].night.begin_time = mktime(tm);
                   /* Check New Year */
 	    				if((current_month == 11) && (tm->tm_mon == 0)){
-					    sprintf(date_in_string,"%s %i %s",weather_days[count_day-1].date,year+1,temp_xml_string);
+					    sprintf(date_in_string,"%s %i %s",app->weather_days[count_day-1].date,year+1,temp_xml_string);
 					    strptime(date_in_string, "%b %d %Y %I:%M %p", tm);
-					    weather_days[count_day-1].night.begin_time = mktime(tm);
+					    app->weather_days[count_day-1].night.begin_time = mktime(tm);
 					}
 				    }
 				    xmlFree(temp_xml_string);    
