@@ -548,6 +548,9 @@ void weather_window_add_station(GtkWidget *widget,
     gtk_widget_show_all(window_add_station);
     gtk_combo_box_set_row_span_column((GtkComboBox*)countrys, 0);
     gtk_combo_box_set_model((GtkComboBox*)countrys, (GtkTreeModel*)app->countrys_list);
+    gtk_widget_set_size_request(GTK_WIDGET(countrys), 350, -1);
+    gtk_widget_set_size_request(GTK_WIDGET(states), 350, -1);
+    gtk_widget_set_size_request(GTK_WIDGET(stations), 350, -1);
 /* Set default value to country combo_box */
     gtk_combo_box_set_active(GTK_COMBO_BOX(countrys),
 				get_active_item_index((GtkTreeModel*)app->countrys_list,
@@ -777,18 +780,18 @@ void weather_window_settings(GtkWidget *widget,
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
         			1, 2, 3, 4);
     gtk_container_add(GTK_CONTAINER(label),icon_size = gtk_combo_box_new_text());
-    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Giant"));    
-    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Large"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Medium"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Small"));
     gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Tiny"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Small"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Medium"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Large"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Giant"));    
     switch(app->config->icons_size){
+	case TINY: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size), TINY - 1);break;
+	case SMALL: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size), SMALL - 1);break;
+	case MEDIUM: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size), MEDIUM - 1);break;
 	default:
-	case GIANT: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),0);break;	
-	case LARGE: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),1);break;	
-	case MEDIUM: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),2);break;
-	case SMALL: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),3);break;
-	case TINY: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),4);break;
+	case LARGE: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size), LARGE - 1);break;
+	case GIANT: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size), GIANT - 1);break;
     }
 /* Font color */   
     gtk_table_attach_defaults(GTK_TABLE(table),	    
@@ -1011,8 +1014,8 @@ void weather_window_settings(GtkWidget *widget,
 	    }
 	    g_free(temp_string);
 /* icon size */	    
-	    if(app->config->icons_size != gtk_combo_box_get_active(GTK_COMBO_BOX(icon_size))){
-		app->config->icons_size = gtk_combo_box_get_active(GTK_COMBO_BOX(icon_size));
+	    if(app->config->icons_size != gtk_combo_box_get_active(GTK_COMBO_BOX(icon_size)) + 1){
+		app->config->icons_size = gtk_combo_box_get_active(GTK_COMBO_BOX(icon_size)) + 1;
 		flag_update_icon = TRUE;
 		flag_tuning_warning = TRUE;
 	    }
@@ -1213,7 +1216,7 @@ void create_help_dialog(void){
 	    "for Nokia 770/N800/N810\n"
 	    "to show weather forecasts.\n"
 	    "Version "), VERSION, 
-	    _("\nCopyright(c) 2006-2007\n"
+	    _("\nCopyright(c) 2006-2008\n"
 	    "Vlad Vasiliev, Pavel Fialko"));
 	    
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
@@ -1262,7 +1265,8 @@ void create_help_dialog(void){
     snprintf(tmp_buff, sizeof(tmp_buff), "%s",
 	    _("French - Nicolas Granziano\n"
 	      "Russian - Pavel Fialko, Vlad Vasiliev,\n\t    Ed Bartosh\n"
-	      "Finnish - Marko Vertainen\n"));
+	      "Finnish - Marko Vertainen\n"
+	      "German - Claudius Henrichs\n"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			create_scrolled_window_with_text(tmp_buff,
 						    GTK_JUSTIFY_LEFT),
