@@ -90,6 +90,7 @@ GtkWidget	*popup_frame = NULL,
     /* Not found pressed button */
     if( i >= app->config->days_to_show )
 	return;
+	i = boxs_offset[i];  
     /* Create POPUP WINDOW */ 
     app->popup_window_more = gtk_window_new( GTK_WINDOW_POPUP );
     gtk_window_set_decorated(GTK_WINDOW(app->popup_window_more), FALSE);
@@ -384,6 +385,8 @@ GtkWidget* create_header_widget(int i){
 		*location_label,
 		*icon,
 		*button,
+		*button_box,
+		*button_label,
 		*date_hbox,
 		*date_label;
     GtkIconInfo *gtkicon_update;
@@ -399,17 +402,17 @@ GtkWidget* create_header_widget(int i){
     }
     else
 	location_label = gtk_label_new(app->config->current_station_name);
-    set_font_color(location_label,0x0000,0x0000,0x0000);
+/*    set_font_color(location_label,0x0000,0x0000,0x0000);*/
 /* prepare icon */
-    gtkicon_update = gtk_icon_theme_lookup_icon(gtk_icon_theme_get_default(),
-        	                        	"qgn_toolb_gene_refresh", 26, 0);
-    icon = gtk_image_new_from_file(gtk_icon_info_get_filename(gtkicon_update));
-    gtk_icon_info_free(gtkicon_update);
+    icon =gtk_image_new_from_icon_name("qgn_toolb_gene_refresh",
+                                         GTK_ICON_SIZE_INVALID);
+    gtk_image_set_pixel_size(GTK_IMAGE(icon), 26);
+
 /* prepare button */    
     button = gtk_button_new();
-    gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
     gtk_button_set_focus_on_click(GTK_BUTTON(button), FALSE);
-    gtk_container_add(GTK_CONTAINER(button), icon);
+    gtk_button_set_image(GTK_BUTTON(button), icon);
+
     gtk_widget_set_events(button, GDK_BUTTON_PRESS_MASK);
     g_signal_connect(button, "clicked",
 		    	    G_CALLBACK(pre_update_weather), NULL);      
@@ -433,7 +436,7 @@ GtkWidget* create_header_widget(int i){
 	strftime(buffer, sizeof(buffer) - 1, "%A %d %B", &tmp_time_date_struct);
         date_label = gtk_label_new(buffer);
 	set_font_size(date_label, 16); 
-	set_font_color(date_label,0x0000,0x0000,0x0000);
+/*	set_font_color(date_label,0x0000,0x0000,0x0000);*/
 	gtk_box_pack_start(GTK_BOX(date_hbox), date_label, FALSE, FALSE, 5);
     }
 /* prepare main vbox */
@@ -538,7 +541,7 @@ GtkWidget* create_current_weather_widget(void){
 					: ( strcat(buffer, _("F")) );
     temperature_label = gtk_label_new(buffer);
     set_font_size(temperature_label, 14);
-    set_font_color(temperature_label,0x0000,0x0000,0x0000);
+/*    set_font_color(temperature_label,0x0000,0x0000,0x0000);*/
     gtk_box_pack_start(GTK_BOX(temperature_vbox), temperature_label, FALSE, FALSE, 0);
     
 /* prepare "feels like", "visible", "pressure", "humidity", "wind", "gust" */
@@ -603,7 +606,7 @@ GtkWidget* create_current_weather_widget(void){
     main_data_vbox = gtk_vbox_new(FALSE, 0);	
     main_data_label = gtk_label_new(buffer);
     set_font_size(main_data_label, 17);
-    set_font_color(main_data_label,0x0000,0x0000,0x0000);
+/*    set_font_color(main_data_label,0x0000,0x0000,0x0000);*/
     gtk_box_pack_start(GTK_BOX(main_data_vbox), main_data_label,
 			    FALSE, FALSE, 0);
 /* prepare icon and temperature vbox */
@@ -675,7 +678,7 @@ GtkWidget* create_temperature_range_widget(int i){
     /* prepare temperature hbox */
     temperature_value_label = gtk_label_new(buffer);
     set_font_size(temperature_value_label, 18);
-    set_font_color(temperature_value_label, 0x0000, 0x0000, 0x0000);
+/*    set_font_color(temperature_value_label, 0x0000, 0x0000, 0x0000);*/
     main_widget = gtk_hbox_new(FALSE, 10);
     temperature_title_label = gtk_label_new(_("Temperature: "));
     set_font_size(temperature_title_label, 16);
@@ -734,7 +737,7 @@ GtkWidget* create_24_hours_widget(int i){
 /* prepare night label */
     night_label = gtk_label_new(_("Night:"));
     set_font_size(night_label, 14);
-    set_font_color(night_label,0x0000,0x0000,0x0000);            
+/*    set_font_color(night_label,0x0000,0x0000,0x0000);*/
 /* preapare night data */
     memset(buffer, 0, sizeof(buffer));
     if(i < Max_count_weather_day);
@@ -753,7 +756,7 @@ GtkWidget* create_24_hours_widget(int i){
 			(char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units]));
     night_data_label = gtk_label_new(buffer);    
     set_font_size(night_data_label, 17);
-    set_font_color(night_data_label,0x0000,0x0000,0x0000);                
+/*    set_font_color(night_data_label,0x0000,0x0000,0x0000);*/
 /* prepare icon and label vbox */
     night_icon_label_vbox = gtk_vbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(night_icon_label_vbox), night_label, FALSE, FALSE, 0);
@@ -774,7 +777,7 @@ GtkWidget* create_24_hours_widget(int i){
 /* prepare day label */
     day_label = gtk_label_new(_("Day:"));
     set_font_size(day_label, 14);
-    set_font_color(day_label,0x0000,0x0000,0x0000);                
+/*    set_font_color(day_label,0x0000,0x0000,0x0000);*/
 /* preapare day data */
     memset(buffer, 0, sizeof(buffer));
     if (i < Max_count_weather_day)
@@ -793,7 +796,7 @@ GtkWidget* create_24_hours_widget(int i){
 			(char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units]));
     day_data_label = gtk_label_new(buffer);    
     set_font_size(day_data_label, 17);
-    set_font_color(day_data_label,0x0000,0x0000,0x0000);                
+/*    set_font_color(day_data_label,0x0000,0x0000,0x0000);*/
 /* prepare icon and label vbox */
     day_icon_label_vbox = gtk_vbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(day_icon_label_vbox), day_label, FALSE, FALSE, 0);
@@ -894,7 +897,7 @@ GtkWidget* create_sun_time_widget(int i){
 
     main_label = gtk_label_new(buffer);
     set_font_size(main_label, 17);
-    set_font_color(main_label, 0x0000, 0x0000, 0x0000);
+/*    set_font_color(main_label, 0x0000, 0x0000, 0x0000);*/
     main_widget = gtk_hbox_new(FALSE, 10);
     
     /* Packing all to the box */
@@ -923,7 +926,7 @@ GtkWidget* create_moon_phase_widget(void){
 			(char*)hash_table_find((gpointer)app->weather_current_day.day.moon));
     main_label = gtk_label_new(buffer);
     set_font_size(main_label, 17);
-    set_font_color(main_label,0x0000,0x0000,0x0000);    
+/*    set_font_color(main_label,0x0000,0x0000,0x0000);*/
 
     main_widget = gtk_hbox_new(FALSE, 10);
 
@@ -980,7 +983,7 @@ GtkWidget* create_time_updates_widget(void){
     }
     label_update = gtk_label_new(buffer);    
     set_font_size(label_update, 14);
-    set_font_color(label_update,0x0000,0x0000,0x0000);
+/*    set_font_color(label_update,0x0000,0x0000,0x0000);*/
     main_widget = gtk_hbox_new(FALSE, 10);
     gtk_box_pack_start(GTK_BOX(main_widget), label_update, FALSE, FALSE, 0);
 
